<?php

namespace Bidl\Php\Core;

use Bidl\Php\Core\Builtins\UnknownError;
use GuzzleHttp\Client;

class BidlClient
{

    public function __construct(public string $baseUrl, public Client $client)
    {
    }

    public function call(
        string $string,
        $request,
        BidlResponse $responseWrapper,
        $headers,
    ) {
        $json = null;
        $status = null;

        try {
            $response = $this->client->post(
              trim($this->baseUrl, '/').'/'.trim($string, '/'),
              [
                'headers' => $headers,
                'json' => $request,
                'http_errors' => false,
              ]
            );
            $status = $response->getStatusCode();
            $json = json_decode($response->getBody()->getContents());

            $responseWrapper->fromJson($json);

            return $responseWrapper->response;
        } catch (\Exception $e) {
            if ($json != null || $status != null) {
                return new UnknownError("An error occurred attempting to deserialize the response.", $status, $json);
            }

            return new UnknownError($e->getMessage());
        }
    }


}